@@ -36,6 +36,11 @@ casing_section_description_schema = Map(
         Optional("material_above_filler"): Str(),
     }
 )
+combined_fluid_description_schema = Map(
+    {
+        Optional("pvt_model"): Str(),
+    }
+)
 composition_description_schema = Map(
     {
         "component": Str(),
@@ -68,6 +73,13 @@ controller_output_signal_properties_description_schema = Map(
         Optional("max_rate_of_change"): Float(),
     }
 )
+controller_trend_description_schema = Map(
+    {
+        Optional("name"): Str(),
+        "curve_names": Seq(Str()),
+        "element_name": Str(),
+    }
+)
 cv_table_description_schema = Map(
     {
         Optional("opening"): Map({"values": Seq(Float()), "unit": Str()}),
@@ -369,7 +381,26 @@ physics_description_schema = Map(
         Optional("initial_condition_strategy"): Enum(['constant', 'steady_state', 'restart']),
         Optional("restart_filepath"): Str(),
         Optional("keep_former_results"): Bool(),
-        Optional("emulsion_model"): Enum(['no_model', 'model_default', 'taylor1932', 'brinkman1952', 'mooney1951a', 'mooney1951b', 'hinze1955', 'sleicher1962', 'brauner2001', 'boxall2012', 'brinkman1952_and_yeh1964', 'from_plugin']),
+        Optional("emulsion_model_enabled"): Bool(),
+        Optional("emulsion_relative_viscosity_model"): Enum(['model_default', 'taylor1932', 'brinkman1952', 'mooney1951a', 'mooney1951b', 'pal_rhodes1989', 'ronningsen1995', 'volumetric_weight', 'woelflin_1942', 'barnea_mizrahi1976', 'table_based', 'from_plugin']),
+        Optional("emulsion_pal_rhodes_phi_rel_100"): Map({"value": Float(), "unit": Str()}),
+        Optional("emulsion_woelflin_a"): Map({"value": Float(), "unit": Str()}),
+        Optional("emulsion_woelflin_b"): Map({"value": Float(), "unit": Str()}),
+        Optional("emulsion_table_based_rel_visc_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("emulsion_relative_viscosity_tuning_factor"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("emulsion_droplet_size_model"): Enum(['model_default', 'hinze1955', 'sleicher1962', 'brauner2001', 'boxall2012']),
+        Optional("emulsion_inversion_point_model"): Enum(['model_default', 'brauner_and_ullmann_2002', 'brinkman1952_and_yeh1964', 'constant']),
+        Optional("emulsion_inversion_water_cut"): Map({"value": Float(), "unit": Str()}),
         Optional("flash_model"): Enum(['hydrocarbon_only', 'hydrocarbon_and_water']),
         Optional("correlations_package"): Enum(['correlation_package_classical', 'correlation_package_alfasim', 'correlation_package_isdb_tests']),
     }
@@ -522,6 +553,11 @@ pvt_model_correlation_description_schema = Map(
         Optional("gas_density_std"): Map({"value": Float(), "unit": Str()}),
         Optional("rs_sat"): Map({"value": Float(), "unit": Str()}),
         Optional("pvt_correlation_package"): Enum(['pvt_correlation_package_lasater', 'pvt_correlation_package_standing', 'pvt_correlation_package_vazquez_beggs', 'pvt_correlation_package_glaso']),
+        Optional("h2s_mol_frac"): Map({"value": Float(), "unit": Str()}),
+        Optional("co2_mol_frac"): Map({"value": Float(), "unit": Str()}),
+        Optional("oil_viscosity"): Enum(['Egbogah']),
+        Optional("gas_viscosity"): Enum(['Lee Gonzalez Eakin']),
+        Optional("surface_tension"): Enum(['Baker Swerdloff']),
     }
 )
 referenced_pressure_container_description_schema = Map(
@@ -748,6 +784,12 @@ casing_description_schema = Map(
         Optional("open_holes"): Seq(open_hole_description_schema),
     }
 )
+compositional_fluid_description_schema = Map(
+    {
+        Optional("composition"): Seq(composition_description_schema),
+        Optional("fraction_pairs"): Seq(bip_description_schema),
+    }
+)
 compressor_equipment_description_schema = Map(
     {
         "position": Map({"value": Float(), "unit": Str()}),
@@ -781,12 +823,6 @@ environment_description_schema = Map(
         Optional("tvd_properties_table"): Seq(environment_property_description_schema),
     }
 )
-fluid_description_schema = Map(
-    {
-        Optional("composition"): Seq(composition_description_schema),
-        Optional("fraction_pairs"): Seq(bip_description_schema),
-    }
-)
 formation_description_schema = Map(
     {
         "reference_y_coordinate": Map({"value": Float(), "unit": Str()}),
@@ -881,13 +917,30 @@ profile_description_schema = Map(
 pump_equipment_description_schema = Map(
     {
         "position": Map({"value": Float(), "unit": Str()}),
-        Optional("type"): Enum(['constant_pressure', 'table_interpolation']),
-        Optional("pressure_boost"): Map({"value": Float(), "unit": Str()}),
+        Optional("flow_direction"): Enum(['forward', 'backward']),
         Optional("thermal_efficiency"): Map({"value": Float(), "unit": Str()}),
+        Optional("type"): Enum(['constant_pressure', 'table_interpolation', 'electric_submersible_pump']),
+        Optional("pressure_boost"): Map({"value": Float(), "unit": Str()}),
         Optional("table"): table_pump_description_schema,
         Optional("speed_curve"): speed_curve_description_schema,
         Optional("speed_curve_interpolation_type"): Enum(['constant', 'linear', 'quadratic']),
-        Optional("flow_direction"): Enum(['forward', 'backward']),
+        Optional("esp_table"): table_pump_description_schema,
+        Optional("esp_speed_input_type"): Enum(['constant', 'curve']),
+        Optional("esp_speed"): Map({"value": Float(), "unit": Str()}),
+        Optional("esp_speed_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("esp_number_of_stages"): Int(),
+        Optional("esp_reference_density"): Map({"value": Float(), "unit": Str()}),
+    }
+)
+pvt_model_combined_description_schema = Map(
+    {
+        Optional("reference_pvt_model"): Str(),
+        Optional("fluids"): MapPattern(Str(), combined_fluid_description_schema),
     }
 )
 table_ipr_description_schema = Map(
@@ -979,7 +1032,7 @@ pvt_model_compositional_description_schema = Map(
         Optional("viscosity_model"): Enum(['corresponding_states_principle', 'lohrenz_bray_clark']),
         Optional("heavy_components"): Seq(heavy_component_description_schema),
         Optional("light_components"): Seq(light_component_description_schema),
-        Optional("fluids"): MapPattern(Str(), fluid_description_schema),
+        Optional("fluids"): MapPattern(Str(), compositional_fluid_description_schema),
     }
 )
 trends_output_description_schema = Map(
@@ -989,6 +1042,7 @@ trends_output_description_schema = Map(
         Optional("global_trends"): Seq(global_trend_description_schema),
         Optional("equipment_trends"): Seq(equipment_trend_description_schema),
         Optional("separator_trends"): Seq(separator_trend_description_schema),
+        Optional("controller_trends"): Seq(controller_trend_description_schema),
     }
 )
 annulus_description_schema = Map(
@@ -1023,6 +1077,8 @@ pipe_description_schema = Map(
         Optional("environment"): environment_description_schema,
         Optional("segments"): pipe_segments_description_schema,
         Optional("initial_conditions"): initial_conditions_description_schema,
+        Optional("flow_pattern_model"): Enum(['unit_cell', 'regime_capturing']),
+        Optional("regime_capturing_mesh_threshold"): Map({"value": Float(), "unit": Str()}),
     }
 )
 pvt_models_description_schema = Map(
@@ -1030,7 +1086,8 @@ pvt_models_description_schema = Map(
         Optional("default_model"): Str(),
         Optional("tables"): MapPattern(Str(), Str()),
         Optional("correlations"): MapPattern(Str(), pvt_model_correlation_description_schema),
-        Optional("compositions"): MapPattern(Str(), pvt_model_compositional_description_schema),
+        Optional("compositional"): MapPattern(Str(), pvt_model_compositional_description_schema),
+        Optional("combined"): MapPattern(Str(), pvt_model_combined_description_schema),
     }
 )
 well_description_schema = Map(
@@ -1066,5 +1123,5 @@ case_description_schema = Map(
         Optional("walls"): Seq(wall_description_schema),
     }
 )
-# [[[end]]] (checksum: b15791693ba5dce623dd301a851d625e)
+# [[[end]]] (checksum: f1c874c32714ece81b49496d4dc106a0)
 # fmt: on
