@@ -1785,15 +1785,13 @@ def calculate_relative_emulsion_viscosity(
     mu_disp: "double",
     mu_cont: "double",
     alpha_disp_in_layer: "double",
-    disp_field_index: "int",
-    cont_field_index: "int",
+    T: "double",
+    water_in_oil: "bool",
 ) -> "int":
     """
-    **c++ signature** : ``HOOK_RELATIVE_EMULSION_VISCOSITY(void* ctx, double* mu_r, double mu_disp, double mu_cont, double alpha_disp_in_layer)``
+    **c++ signature** : ``HOOK_RELATIVE_EMULSION_VISCOSITY(void* ctx, double* mu_r, double mu_disp, double mu_cont, double alpha_disp_in_layer, double T, bool water_in_oil)``
 
-    Internal `hook` to calculate the relative emulsion viscosity in the Emulsion Model.
-    This `hook` will be used in the emulsion model to calculate the apparent viscosity of the emulsion
-    (Continuous field + dispersed field = layer).
+    Internal `hook` to calculate the relative emulsion viscosity of an oil-water dispersion (emulsion)
 
     The relative emulsion viscosity is defined by:
 
@@ -1812,8 +1810,8 @@ def calculate_relative_emulsion_viscosity(
 
     The output variable ``mu_r`` is the relative emulsion viscosity, ``mu_disp`` is the dispersed field
     viscosity, ``mu_cont`` is the continuous field viscosity and ``alpha_disp_in_layer`` is the volume
-    fraction of dispersed field in the layer. Finally ``disp_field_index`` and ``cont_field_index`` are
-    the Dispersed and Continuous Field indexes of the emulsion, respectively.
+    fraction of dispersed field in the layer (dispersed field plus continuous field), T is the fluid temperature,
+    and water_in_oil is true when water is the dispersed phase and false otherwise.
 
     This `hook` allows the implementation of the relative emulsion viscosity correlation. Once the plugin
     installed it is important to be selected in the emulsion model configuration inside the Physics data
@@ -1824,8 +1822,8 @@ def calculate_relative_emulsion_viscosity(
     :param mu_disp: Dispersed field viscosity
     :param mu_cont: Continuous field viscosity
     :param alpha_disp_in_layer: Volume fraction of dispersed field in layer.
-    :param disp_field_index: Index of the dispersed field
-    :param cont_field_index: Index of the continuous field
+    :param T: Fluid temperature
+    :param water_in_oil: True when water is the dispersed phase
 
     :returns: Return OK if successful or anything different if failed
 
@@ -1835,33 +1833,10 @@ def calculate_relative_emulsion_viscosity(
         :linenos:
         :emphasize-lines: 1
 
-        HOOK_RELATIVE_EMULSION_VISCOSITY(ctx, mu_r, mu_disp, mu_cont, alpha_disp_in_layer)
+        HOOK_RELATIVE_EMULSION_VISCOSITY(ctx, mu_r, mu_disp, mu_cont, alpha_disp_in_layer, T, water_in_oil)
         {
-            int water_in_oil_id = -1;
-            errcode = alfasim_sdk_api.get_field_id(ctx, &water_in_oil_id, "water in oil");
-            if (errcode != OK) {
-                return errcode;
-            }
-
-            int oil_in_water_id = -1;
-            errcode = alfasim_sdk_api.get_field_id(ctx, &oil_in_water_id, "oil in water");
-            if (errcode != OK) {
-                return errcode;
-            }
-
-            if (disp_field_index == oil_in_water_id){
-                // Calculate the relative emulsion viscosity
-                // for water dominated scenario.
-                // ComputeForWaterDominated is a function implemented
-                // by plugin developer
-                ComputeForWaterDominated(mu_r, mu_disp, mu_cont);
-            } else if (disp_field_index == water_in_oil_id){
-                // Calculate the relative emulsion viscosity
-                // for oil dominated scenario
-                // ComputeForOilDominated is a function implemented
-                // by plugin developer
-                ComputeForOilDominated(mu_r, n_faces);
-            }
+            // Einstein (1906) relative viscosity model
+            mu_r = 1.0 + 2.5 * alpha_disp_in_layer;
 
             return OK;
         }
@@ -1906,24 +1881,27 @@ def calculate_entrained_liquid_fraction(
 
 def update_internal_deposition_layer(
     ctx: "void*",
-    thickness: "void*",
+    phase_id: "int*",
+    thickness_variation_rate: "void*",
     density: "void*",
     heat_capacity: "void*",
     thermal_conductivity: "void*",
     n_control_volumes: "int",
 ) -> "int":
     """
-    **c++ signature** : ``HOOK_UPDATE_INTERNAL_DEPOSITION_LAYER(void* ctx, void* thickness, void* density, void* heat_capacity, void* thermal_conductivity,
-    int n_control_volumes)``
+    **c++ signature** : ``HOOK_UPDATE_INTERNAL_DEPOSITION_LAYER(void* ctx, int* phase_id, void* thickness_variation_rate,
+    void* density, void* heat_capacity, void* thermal_conductivity, int n_control_volumes)``
 
-    Internal simulator hook to evaluate the thickness and thermal properties of the deposited layer at the inside of the pipeline walls.
-    This is called for accounting the diameter reduction and wall thermal effects.
+    Internal simulator hook to evaluate the deposition volumetric rate and thermal properties of the deposited layer on
+    pipeline walls. This is called for accounting the inner diameter reduction and wall thermal effects.
 
-    The plugin is supposed to change the given ``thickness``, ``density``, ``heat_capacity``, ``thermal_conductivity`` array pointers. Its values are contiguous
-    in memory and the dimension is given by ``n_control_volumes``. It has unit equal to ``[m]``.
+    The plugin is supposed to change ``thickness_variation_rate``, ``density``, ``heat_capacity``,
+    ``thermal_conductivity`` array pointers, as well as the integer value phase_id. The array pointers must be contiguous
+    in memory and their dimension is given by ``n_control_volumes``.
 
     :param ctx: ALFAsim's plugins context
-    :param thickness: Thickness of the internal deposit layer
+    :param phase_id: Id of phase that is being deposited on pipe walls
+    :param thickness_variation_rate: Rate of change of deposition layer thickness
     :param density: Density of the internal deposit layer [kg/m3]
     :param heat_capacity: Heat capacity of the internal deposit layer [J/(kg.K)]
     :param thermal_conductivity: Thermal conductivity of the internal deposit layer [W/(m.K)]
@@ -1937,7 +1915,7 @@ def update_internal_deposition_layer(
         :emphasize-lines: 1
 
         HOOK_UPDATE_INTERNAL_DEPOSITION_LAYER(
-            ctx, thickness, density, heat_capacity, thermal_conductivity, n_control_volumes)
+            ctx, phase_id, thickness_variation_rate, density, heat_capacity, thermal_conductivity, n_control_volumes)
         {
             auto errcode = -1;
 
@@ -1948,7 +1926,14 @@ def update_internal_deposition_layer(
                 return errcode;
             }
 
-            // Handle first time step, because you won't have the previously information
+            int phase_wax_id = -1;
+            errcode = alfasim.get_phase_id(ctx, &phase_wax_id, "wax");
+            if (errcode != 0) {
+                return errcode;
+            }
+            *phase_id = phase_wax_id;
+
+            // Handle first time step. At this point there is no data from previous time step.
             double current_time = -1.0;
             errcode = alfasim.get_simulation_quantity(
                 ctx, &current_time, TimestepScope::CURRENT, (char*) "time");
@@ -1963,34 +1948,18 @@ def update_internal_deposition_layer(
             if (current_time == 0.0){
                 // Set a value for the deposition layer thickness
                  for (int i = 0; i < n_control_volumes; ++i) {
-                   (double*) thickness[i] = 0.0; // [m]
+                   (double*) thickness_variation_rate[i] = 0.0; // [m]
                    (double*) density[i] = wax_density; // [kg/m3]
                    (double*) heat_capacity[i] = wax_heat_capacity; //  [J/(kg.K)]
                    (double*) thermal_conductivity[i] = wax_thermal_conductivity; // [W/(m.K)]
                 }
             } else{
-                // Get previously deposition layer thickness to obtain the current
-                void* thickness_old_raw_ptr;
-                errcode = alfasim.get_plugin_variable(
-                    ctx,
-                    &thickness_old_raw_ptr,
-                    "thickness",
-                    0,
-                    TimestepScope::PREVIOUS,
-                    &size);
-                if (errcode != 0) {
-                    return errcode;
-                }
-                auto* thickness_old =
-                    (double*) (thickness_old_raw_ptr);
-
                 // Calculate the variation of the deposition layer in one time step
                 double* d_deposit_layer_dt = 0.0001; // [m/s]
 
                 // Sum this variation with the thickness of the older time step
                 for (int i = 0; i < n_control_volumes; ++i) {
-                    (double*) thickness[i] =
-                        thickness_old[i] + d_deposit_layer_dt * dt; // [m]
+                    (double*) thickness_variation_rate[i] = d_deposit_layer_dt; // [m3/s]
                    (double*) density[i] = wax_density; // [kg/m3]
                    (double*) heat_capacity[i] = wax_heat_capacity; //  [J/(kg.K)]
                    (double*) thermal_conductivity[i] = wax_thermal_conductivity; // [W/(m.K)]
