@@ -604,6 +604,20 @@ DLL_EXPORT int get_liqliq_flow_pattern(
     int* size
 );
 
+/*!
+    Returns the thickness of the deposition of phase on pipe inner wall.
+
+    @param[in] ctx ALFAsim's plugins context.
+    @param[out] out Thickness of phase deposited on inner wall.
+    @param[in] phase_id Phase index.
+    @param[in] ts_scope A #TimestepScope value.
+    @param[in] size Size of out array of values.
+    @return An #error_code value.
+*/
+DLL_EXPORT int get_deposition_thickness(
+   void* ctx, double** out, int phase_id, enum TimestepScope ts_scope, int* size
+);
+
 /*!
     Retrieves the tracer ID given a tracer reference. A tracer reference may be obtained from the
     user input data (See #get_plugin_input_data_reference API function for an example).
@@ -894,13 +908,9 @@ DLL_EXPORT int get_liq_liq_shear_force_per_volume_input_variable(
     @param[in] mu_disp Dispersed Field Viscosity [Pa.s].
     @param[in] mu_cont Continuous Field Viscosity [Pa.s].
     @param[in] alpha_disp_in_layer Dispersed Field Volume Fraction in the layer (emulsion) [m3 of dispersed field /m3 of layer].
-    @param[in] disp_field_id  Dispersed Field Id (Can be "oil in water" or "water in oil" fields).
-    @param[in] cont_field_id  Continuous Field Id (Can be "oil" or "water" fields).
+    @param[in] T Fluid temperature [K].
+    @param[in] water_in_oil True when water is dispersed in oil, otherwise it is a dispersion of oil in water.
     @return An #error_code value.
-
-    It is important to know that `disp_field_id` and `cont_field_id` must be passed because
-    the emulsion model can have different correlations for each one.
-    To use the correct Field Ids the API function #get_field_id must be used.
 */
 DLL_EXPORT int get_relative_emulsion_viscosity(
     void* ctx,
@@ -908,8 +918,8 @@ DLL_EXPORT int get_relative_emulsion_viscosity(
     double mu_disp,
     double mu_cont,
     double alpha_disp_in_layer,
-    int disp_field_id,
-    int cont_field_id
+    double T,
+    bool water_in_oil
 );
 
 #endif
